#!/bin/tcsh
set root=zroot/root

@ j=0
foreach i ( 8 10 12 14 16 18 )
  gpart create -s gpt ad$i
  gpart add -b 63 -s 64k -t freebsd-boot ad$i
  gpart add -t freebsd-zfs -l disk$j ad$i
  gpart bootcode -b pmbr -p gptzfsboot -i 1 ad$i
  @ j++
end

ln -s /dist/boot/kernel /boot/kernel; ln -s /dist/lib /lib; kldload geom_eli; kldload zfs

gnop create -S 4096 /dev/gpt/disk0

mkdir /boot/zfs; zpool create zroot raidz2 /dev/gpt/disk0.nop /dev/gpt/disk[1-5]; zfs create ${root}; zpool set bootfs=${root} zroot
zpool export zroot; gnop destroy /dev/gpt/disk0.nop; zpool import zroot

zfs set checksum=fletcher4                                      ${root}
zfs create -o compression=on    -o exec=on      -o setuid=off   ${root}/tmp
chmod 1777 /${root}/tmp
zfs create                                                      ${root}/usr
zfs create                                                      ${root}/usr/home
cd /${root} ; ln -s /usr/home home
zfs create -o compression=lzjb                  -o setuid=off   ${root}/usr/ports
zfs create -o compression=off   -o exec=off     -o setuid=off   ${root}/usr/ports/distfiles
zfs create -o compression=off   -o exec=off     -o setuid=off   ${root}/usr/ports/packages

zfs create -o compression=lzjb  -o exec=off     -o setuid=off   ${root}/usr/src
zfs create                                                      ${root}/var
zfs create -o compression=lzjb  -o exec=off     -o setuid=off   ${root}/var/crash
zfs create                      -o exec=off     -o setuid=off   ${root}/var/db
zfs create -o compression=lzjb  -o exec=on      -o setuid=off   ${root}/var/db/pkg
zfs create                      -o exec=off     -o setuid=off   ${root}/var/empty
zfs create -o compression=lzjb  -o exec=off     -o setuid=off   ${root}/var/log
zfs create -o compression=gzip  -o exec=off     -o setuid=off   ${root}/var/mail
zfs create                      -o exec=off     -o setuid=off   ${root}/var/run
zfs create -o compression=lzjb  -o exec=on      -o setuid=off   ${root}/var/tmp
chmod 1777 /${root}/var/tmp

cd /dist/8.2*
setenv DESTDIR /${root}
foreach dir (base catpages dict doc games info manpages ports)
cd $dir
./install.sh
cd ..
end
cd src ; ./install.sh all
cd ../kernels ; ./install.sh generic
cd /${root}/boot ; cp -Rlp GENERIC/?* /${root}/boot/kernel/

zfs set readonly=on ${root}/var/empty

cat << EOF > /${root}/setup.sh
passwd; tzsetup

cd /etc/mail
make aliases
umount /dev
exit
EOF

chmod +x /${root}/setup.sh
chroot /${root} /setup.sh

rm /${root}/setup.sh

cat << EOF > /${root}/etc/rc.conf
zfs_enable="YES"
hostname="mira.local"
ifconfig_em0="DHCP"
sshd_enable="YES"
EOF

echo zfs_load="YES" > /${root}/boot/loader.conf
echo vfs.root.mountfrom="zfs:${root}" >> /${root}/boot/loader.conf

cp /root/zfsloader /${root}/boot/
cp /boot/zfs/zpool.cache /${root}/boot/zfs/zpool.cache

#cat << EOF > /${root}/etc/fstab
## Device                       Mountpoint              FStype  Options         Dump    Pass#
#/dev/gpt/swap0                 none                    swap    sw              0       0
#/dev/gpt/swap1                 none                    swap    sw              0       0
#/dev/gpt/swap2                 none                    swap    sw              0       0
#/dev/gpt/swap3                 none                    swap    sw              0       0
#EOF

cd

zfs unmount -a
zfs set mountpoint=legacy ${root}
zfs set mountpoint=/tmp ${root}/tmp
zfs set mountpoint=/usr ${root}/usr
zfs set mountpoint=/var ${root}/var
